@@ -1,13 +1,13 @@
 "use strict";
 
-var _ = require("lodash");
+let _ = require("lodash");
 
 module.exports.resolveApi = function (sense_version, apis, reply) {
-  var result = {};
+  let result = {};
   _.each(apis, function (name) {
     {
       // for now we ignore sense_version. might add it in the api name later
-      var api = require('./' + name);
+      let api = require('./' + name);
       result[name] = api.asJson();
     }
   });
