@@ -1,9 +1,9 @@
 import _ from 'lodash';
-import docViewsRegistry from 'ui/registry/doc_views';
+import { DocViewsRegistryProvider } from 'ui/registry/doc_views';
 
 import tableHtml from './table.html';
 
-docViewsRegistry.register(function () {
+DocViewsRegistryProvider.register(function () {
   return {
     title: 'Table',
     order: 10,
@@ -13,7 +13,9 @@ docViewsRegistry.register(function () {
         hit: '=',
         indexPattern: '=',
         filter: '=',
-        columns: '='
+        columns: '=',
+        onAddColumn: '=',
+        onRemoveColumn: '=',
       },
       controller: function ($scope) {
         $scope.mapping = $scope.indexPattern.fields.byName;
@@ -21,12 +23,23 @@ docViewsRegistry.register(function () {
         $scope.formatted = $scope.indexPattern.formatHit($scope.hit);
         $scope.fields = _.keys($scope.flattened).sort();
 
-        $scope.toggleColumn = function (fieldName) {
-          _.toggleInOut($scope.columns, fieldName);
+        $scope.canToggleColumns = function canToggleColumn() {
+          return (
+            _.isFunction($scope.onAddColumn)
+            && _.isFunction($scope.onRemoveColumn)
+          );
+        };
+
+        $scope.toggleColumn = function toggleColumn(columnName) {
+          if ($scope.columns.includes(columnName)) {
+            $scope.onRemoveColumn(columnName);
+          } else {
+            $scope.onAddColumn(columnName);
+          }
         };
 
         $scope.showArrayInObjectsWarning = function (row, field) {
-          let value = $scope.flattened[field];
+          const value = $scope.flattened[field];
           return _.isArray(value) && typeof value[0] === 'object';
         };
       }
