@@ -4,9 +4,8 @@
 import moment from 'moment-timezone';
 import chrome from 'ui/chrome';
 import routes from 'ui/routes';
-import modules from 'ui/modules';
+import { uiModules } from 'ui/modules';
 
-import kibanaLogoUrl from 'ui/images/kibana.svg';
 import 'ui/autoload/all';
 import 'plugins/kibana/discover/index';
 import 'plugins/kibana/visualize/index';
@@ -14,11 +13,12 @@ import 'plugins/kibana/dashboard/index';
 import 'plugins/kibana/management/index';
 import 'plugins/kibana/doc';
 import 'plugins/kibana/dev_tools';
+import 'plugins/kibana/context';
 import 'ui/vislib';
 import 'ui/agg_response';
 import 'ui/agg_types';
 import 'ui/timepicker';
-import Notifier from 'ui/notify/notifier';
+import { Notifier } from 'ui/notify/notifier';
 import 'leaflet';
 
 routes.enable();
@@ -48,4 +48,4 @@ chrome
   }
 });
 
-modules.get('kibana').run(Notifier.pullMessageFromUrl);
+uiModules.get('kibana').run(Notifier.pullMessageFromUrl);
