@@ -1,5 +1,5 @@
-import VisAggConfigProvider from 'ui/vis/agg_config';
-import uiModules from 'ui/modules';
+import { VisAggConfigProvider } from 'ui/vis/agg_config';
+import { uiModules } from 'ui/modules';
 import aggAddTemplate from 'plugins/kibana/visualize/editor/agg_add.html';
 
 uiModules
