@@ -16,18 +16,25 @@ import 'plugins/kibana/visualize/editor/draggable_item';
 import 'plugins/kibana/visualize/editor/draggable_handle';
 import 'plugins/kibana/visualize/saved_visualizations/_saved_vis';
 import 'plugins/kibana/visualize/saved_visualizations/saved_visualizations';
+import 'ui/directives/scroll_bottom';
+import 'ui/filters/sort_prefix_first';
 import uiRoutes from 'ui/routes';
-
+import visualizeListingTemplate from './listing/visualize_listing.html';
+import { VisualizeListingController } from './listing/visualize_listing';
+import { VisualizeConstants } from './visualize_constants';
+import { SavedObjectRegistryProvider } from 'ui/saved_objects/saved_object_registry';
+import { savedVisualizationProvider } from 'plugins/kibana/visualize/saved_visualizations/saved_visualization_register';
 
 uiRoutes
 .defaults(/visualize/, {
   requireDefaultIndex: true
 })
-.when('/visualize', {
-  redirectTo: '/visualize/step/1'
+.when(VisualizeConstants.LANDING_PAGE_PATH, {
+  template: visualizeListingTemplate,
+  controller: VisualizeListingController,
+  controllerAs: 'listingController',
 });
 
 // preloading
 
-require('ui/saved_objects/saved_object_registry')
-.register(require('plugins/kibana/visualize/saved_visualizations/saved_visualization_register'));
+SavedObjectRegistryProvider.register(savedVisualizationProvider);
