@@ -1,12 +1,11 @@
-var _ = require('lodash');
-var $ = require('jquery');
+import _ from 'lodash';
 
 require('angular-sortable-view');
 require('plugins/timelion/directives/chart/chart');
 require('plugins/timelion/directives/timelion_grid');
 
-var app = require('ui/modules').get('apps/timelion', ['angular-sortable-view']);
-var html = require('./cells.html');
+const app = require('ui/modules').get('apps/timelion', ['angular-sortable-view']);
+import html from './cells.html';
 
 app.directive('timelionCells', function () {
   return {
@@ -19,7 +18,7 @@ app.directive('timelionCells', function () {
       onSelect: '=',
     },
     template: html,
-    link: function ($scope, $elem) {
+    link: function ($scope) {
 
       $scope.removeCell = function (index) {
         _.pullAt($scope.state.sheet, index);
