@@ -1,4 +1,4 @@
-define(function (require) {
+define(function () {
   return function savedSearchObjectFn(savedSheets) {
     return savedSheets;
   };
