@@ -1,7 +1,10 @@
 'use strict';
 
-var _ = require('lodash');
-var moment = require('moment');
+var _lodash = require('lodash');
+
+var _lodash2 = _interopRequireDefault(_lodash);
+
+function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
 
 // Upsampling of non-cummulative sets
 // Good: average, min, max
@@ -11,13 +14,13 @@ var moment = require('moment');
 module.exports = function (dataTuples, targetTuples) {
 
   if (dataTuples.length > targetTuples.length) {
-    throw new Error('Don\'t use the \'carry\' fit method to down sample, use \'scale\' or \'average\'');
+    throw new Error(`Don't use the 'carry' fit method to down sample, use 'scale' or 'average'`);
   }
 
-  var currentCarry = dataTuples[0][1];
-  return _.map(targetTuples, function (bucket, h) {
-    var targetTime = bucket[0];
-    var dataTime = dataTuples[0][0];
+  let currentCarry = dataTuples[0][1];
+  return _lodash2.default.map(targetTuples, function (bucket) {
+    const targetTime = bucket[0];
+    const dataTime = dataTuples[0][0];
 
     if (dataTuples[0] && targetTime >= dataTime) {
       currentCarry = dataTuples[0][1];
