@@ -1,29 +1,33 @@
 'use strict';
 
-var _ = require('lodash');
+var _lodash = require('lodash');
+
+var _lodash2 = _interopRequireDefault(_lodash);
+
+function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
 
 // Only applies to already resolved arguments
 module.exports = function indexArguments(functionDef, orderedArgs) {
 
-  var validateArg = require('./validate_arg')(functionDef);
+  const validateArg = require('./validate_arg')(functionDef);
 
   // This almost certainly is not required
-  var allowedLength = functionDef.extended ? functionDef.args.length + 2 : functionDef.args.length;
+  const allowedLength = functionDef.extended ? functionDef.args.length + 2 : functionDef.args.length;
   if (orderedArgs.length > allowedLength) throw new Error('Too many arguments passed to: ' + functionDef.name);
 
-  var indexedArgs = {};
+  const indexedArgs = {};
   // Check and index each known argument
-  _.each(functionDef.args, function (argDef, i) {
-    var value = orderedArgs[i];
+  _lodash2.default.each(functionDef.args, function (argDef, i) {
+    const value = orderedArgs[i];
     validateArg(value, argDef.name, argDef);
     indexedArgs[argDef.name] = value;
   });
 
   // Also check and index the extended arguments if enabled
   if (functionDef.extended) {
-    var values = orderedArgs[orderedArgs.length - 1];
-    var names = orderedArgs[orderedArgs.length - 2];
-    _.each(values, function (value, i) {
+    const values = orderedArgs[orderedArgs.length - 1];
+    const names = orderedArgs[orderedArgs.length - 2];
+    _lodash2.default.each(values, function (value, i) {
       validateArg(value, names[i], functionDef.extended);
       indexedArgs[names[i]] = value;
     });
