@@ -1,7 +1,14 @@
 'use strict';
 
-var Promise = require('bluebird');
-var _ = require('lodash');
+var _bluebird = require('bluebird');
+
+var _bluebird2 = _interopRequireDefault(_bluebird);
+
+var _lodash = require('lodash');
+
+var _lodash2 = _interopRequireDefault(_lodash);
+
+function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
 
 /* @param {Array} args
  * - args[0] must be a seriesList
@@ -12,21 +19,21 @@ var _ = require('lodash');
 
 module.exports = function alter(args, fn) {
   // In theory none of the args should ever be promises. This is probably a waste.
-  return Promise.all(args).then(function (args) {
+  return _bluebird2.default.all(args).then(function (args) {
 
-    var seriesList = args.shift();
+    const seriesList = args.shift();
 
     if (seriesList.type !== 'seriesList') {
       throw new Error('args[0] must be a seriesList');
     }
 
-    var list = _.chain(seriesList.list).map(function (series) {
+    const list = _lodash2.default.chain(seriesList.list).map(function (series) {
       return fn.apply(this, [series].concat(args));
     }).flatten().value();
 
     seriesList.list = list;
     return seriesList;
-  })['catch'](function (e) {
+  }).catch(function (e) {
     throw e;
   });
 };
