@@ -1,9 +1,16 @@
 'use strict';
 
-var alter = require('../lib/alter.js');
+var _alter = require('../lib/alter.js');
 
-var Chainable = require('../lib/classes/chainable');
-module.exports = new Chainable('lines', {
+var _alter2 = _interopRequireDefault(_alter);
+
+var _chainable = require('../lib/classes/chainable');
+
+var _chainable2 = _interopRequireDefault(_chainable);
+
+function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
+
+module.exports = new _chainable2.default('lines', {
   args: [{
     name: 'inputSeries',
     types: ['seriesList']
@@ -30,7 +37,7 @@ module.exports = new Chainable('lines', {
   }],
   help: 'Show the seriesList as lines',
   fn: function linesFn(args) {
-    return alter(args, function (eachSeries, width, fill, stack, show, steps) {
+    return (0, _alter2.default)(args, function (eachSeries, width, fill, stack, show, steps) {
       eachSeries.lines = eachSeries.lines || {};
 
       // Defaults
