@@ -1,9 +1,16 @@
 'use strict';
 
-var reduce = require('../lib/reduce.js');
+var _reduce = require('../lib/reduce.js');
 
-var Chainable = require('../lib/classes/chainable');
-module.exports = new Chainable('sum', {
+var _reduce2 = _interopRequireDefault(_reduce);
+
+var _chainable = require('../lib/classes/chainable');
+
+var _chainable2 = _interopRequireDefault(_chainable);
+
+function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
+
+module.exports = new _chainable2.default('sum', {
   args: [{
     name: 'inputSeries',
     types: ['seriesList']
@@ -16,7 +23,7 @@ module.exports = new Chainable('sum', {
   help: 'Adds the values of one or more series in a seriesList to each position, in each series, of the input seriesList',
   aliases: ['add', 'plus'],
   fn: function sumFn(args) {
-    return reduce(args, function (a, b) {
+    return (0, _reduce2.default)(args, function (a, b) {
       return a + b;
     });
   }
