@@ -1,9 +1,10 @@
 import _ from 'lodash';
-import rowsToFeatures from 'ui/agg_response/geo_json/rows_to_features';
-import AggResponseGeoJsonTooltipFormatterProvider from 'ui/agg_response/geo_json/_tooltip_formatter';
-export default function TileMapConverterFn(Private, timefilter, $compile, $rootScope) {
+import { convertRowsToFeatures } from 'ui/agg_response/geo_json/rows_to_features';
+import { TileMapTooltipFormatterProvider } from 'ui/agg_response/geo_json/_tooltip_formatter';
 
-  let tooltipFormatter = Private(AggResponseGeoJsonTooltipFormatterProvider);
+export function AggResponseGeoJsonProvider(Private) {
+
+  const tooltipFormatter = Private(TileMapTooltipFormatterProvider);
 
   return function (vis, table) {
 
@@ -13,13 +14,15 @@ export default function TileMapConverterFn(Private, timefilter, $compile, $rootS
       });
     }
 
-    let geoI = columnIndex('segment');
-    let metricI = columnIndex('metric');
-    let geoAgg = _.get(table.columns, [geoI, 'aggConfig']);
-    let metricAgg = _.get(table.columns, [metricI, 'aggConfig']);
+    const geoI = columnIndex('segment');
+    const metricI = columnIndex('metric');
+    const centroidI = _.findIndex(table.columns, (col) => col.aggConfig.type.name === 'geo_centroid');
 
-    let features = rowsToFeatures(table, geoI, metricI);
-    let values = features.map(function (feature) {
+    const geoAgg = _.get(table.columns, [geoI, 'aggConfig']);
+    const metricAgg = _.get(table.columns, [metricI, 'aggConfig']);
+
+    const features = convertRowsToFeatures(table, geoI, metricI, centroidI);
+    const values = features.map(function (feature) {
       return feature.properties.value;
     });
 
@@ -40,4 +43,4 @@ export default function TileMapConverterFn(Private, timefilter, $compile, $rootS
       }
     };
   };
-};
+}
