@@ -1,26 +1,27 @@
 import _ from 'lodash';
-import AggResponsePointSeriesGetPointProvider from 'ui/agg_response/point_series/_get_point';
-import AggResponsePointSeriesAddToSiriProvider from 'ui/agg_response/point_series/_add_to_siri';
-export default function PointSeriesGetSeries(Private) {
-  let getPoint = Private(AggResponsePointSeriesGetPointProvider);
-  let addToSiri = Private(AggResponsePointSeriesAddToSiriProvider);
+import { PointSeriesGetPointProvider } from 'ui/agg_response/point_series/_get_point';
+import { PointSeriesAddToSiriProvider } from 'ui/agg_response/point_series/_add_to_siri';
+
+export function PointSeriesGetSeriesProvider(Private) {
+  const getPoint = Private(PointSeriesGetPointProvider);
+  const addToSiri = Private(PointSeriesAddToSiriProvider);
 
   return function getSeries(rows, chart) {
-    let aspects = chart.aspects;
-    let multiY = _.isArray(aspects.y);
-    let yScale = chart.yScale;
-    let partGetPoint = _.partial(getPoint, aspects.x, aspects.series, yScale);
+    const aspects = chart.aspects;
+    const multiY = _.isArray(aspects.y);
+    const yScale = chart.yScale;
+    const partGetPoint = _.partial(getPoint, aspects.x, aspects.series, yScale);
 
     let series = _(rows)
     .transform(function (series, row) {
       if (!multiY) {
-        let point = partGetPoint(row, aspects.y, aspects.z);
-        if (point) addToSiri(series, point, point.series);
+        const point = partGetPoint(row, aspects.y, aspects.z);
+        if (point) addToSiri(series, point, point.series, point.series, aspects.y.agg);
         return;
       }
 
       aspects.y.forEach(function (y) {
-        let point = partGetPoint(row, y, aspects.z);
+        const point = partGetPoint(row, y, aspects.z);
         if (!point) return;
 
         // use the point's y-axis as it's series by default,
@@ -35,7 +36,7 @@ export default function PointSeriesGetSeries(Private) {
           seriesLabel = prefix + seriesLabel;
         }
 
-        addToSiri(series, point, seriesId, seriesLabel);
+        addToSiri(series, point, seriesId, seriesLabel, y.agg);
       });
 
     }, new Map())
@@ -44,11 +45,11 @@ export default function PointSeriesGetSeries(Private) {
 
     if (multiY) {
       series = _.sortBy(series, function (siri) {
-        let firstVal = siri.values[0];
+        const firstVal = siri.values[0];
         let y;
 
         if (firstVal) {
-          let agg = firstVal.aggConfigResult.aggConfig;
+          const agg = firstVal.aggConfigResult.aggConfig;
           y = _.find(aspects.y, function (y) {
             return y.agg === agg;
           });
@@ -60,4 +61,4 @@ export default function PointSeriesGetSeries(Private) {
 
     return series;
   };
-};
+}
