@@ -1,18 +1,16 @@
 import _ from 'lodash';
-import VisAggConfigProvider from 'ui/vis/agg_config';
-import AggResponseTabifyResponseWriterProvider from 'ui/agg_response/tabify/_response_writer';
-import AggResponseTabifyBucketsProvider from 'ui/agg_response/tabify/_buckets';
-export default function tabifyAggResponseProvider(Private, Notifier) {
+import { TabbedAggResponseWriterProvider } from 'ui/agg_response/tabify/_response_writer';
+import { AggResponseBucketsProvider } from 'ui/agg_response/tabify/_buckets';
 
-  let AggConfig = Private(VisAggConfigProvider);
-  let TabbedAggResponseWriter = Private(AggResponseTabifyResponseWriterProvider);
-  let Buckets = Private(AggResponseTabifyBucketsProvider);
-  let notify = new Notifier({ location: 'agg_response/tabify'});
+export function AggResponseTabifyProvider(Private, Notifier) {
+  const TabbedAggResponseWriter = Private(TabbedAggResponseWriterProvider);
+  const Buckets = Private(AggResponseBucketsProvider);
+  const notify = new Notifier({ location: 'agg_response/tabify' });
 
   function tabifyAggResponse(vis, esResponse, respOpts) {
-    let write = new TabbedAggResponseWriter(vis, respOpts);
+    const write = new TabbedAggResponseWriter(vis, respOpts);
 
-    let topLevelBucket = _.assign({}, esResponse.aggregations, {
+    const topLevelBucket = _.assign({}, esResponse.aggregations, {
       doc_count: esResponse.hits.total
     });
 
@@ -31,13 +29,13 @@ export default function tabifyAggResponseProvider(Private, Notifier) {
    * @returns {undefined}
    */
   function collectBucket(write, bucket, key) {
-    let agg = write.aggStack.shift();
+    const agg = write.aggStack.shift();
 
     switch (agg.schema.group) {
       case 'buckets':
-        let buckets = new Buckets(bucket[agg.id]);
+        const buckets = new Buckets(bucket[agg.id]);
         if (buckets.length) {
-          let splitting = write.canSplit && agg.schema.name === 'split';
+          const splitting = write.canSplit && agg.schema.name === 'split';
           if (splitting) {
             write.split(agg, buckets, function forEachBucket(subBucket, key) {
               collectBucket(write, subBucket, agg.getKey(subBucket), key);
@@ -63,7 +61,7 @@ export default function tabifyAggResponseProvider(Private, Notifier) {
         }
         break;
       case 'metrics':
-        let value = agg.getValue(bucket);
+        const value = agg.getValue(bucket);
         write.cell(agg, value, function () {
           if (!write.aggStack.length) {
             // row complete
@@ -82,7 +80,7 @@ export default function tabifyAggResponseProvider(Private, Notifier) {
   // write empty values for each bucket agg, then write
   // the metrics from the initial bucket using collectBucket()
   function passEmptyBuckets(write, bucket, key) {
-    let agg = write.aggStack.shift();
+    const agg = write.aggStack.shift();
 
     switch (agg.schema.group) {
       case 'metrics':
@@ -101,4 +99,4 @@ export default function tabifyAggResponseProvider(Private, Notifier) {
   }
 
   return notify.timed('tabify agg response', tabifyAggResponse);
-};
+}
