@@ -1,5 +1,6 @@
-import buildRangeFilter from 'ui/filter_manager/lib/range';
-export default function createRangeFilterProvider(Private) {
+import { buildRangeFilter } from 'ui/filter_manager/lib/range';
+
+export function AggTypesBucketsCreateFilterRangeProvider() {
   return function (aggConfig, key) {
     return buildRangeFilter(
       aggConfig.params.field,
@@ -8,4 +9,4 @@ export default function createRangeFilterProvider(Private) {
       aggConfig.fieldFormatter()(key)
     );
   };
-};
+}
