@@ -1,10 +1,10 @@
-import _ from 'lodash';
-import AggTypesBucketsBucketAggTypeProvider from 'ui/agg_types/buckets/_bucket_agg_type';
-import AggTypesBucketsCreateFilterTermsProvider from 'ui/agg_types/buckets/create_filter/terms';
+import { AggTypesBucketsBucketAggTypeProvider } from 'ui/agg_types/buckets/_bucket_agg_type';
+import { AggTypesBucketsCreateFilterTermsProvider } from 'ui/agg_types/buckets/create_filter/terms';
 import orderAndSizeTemplate from 'ui/agg_types/controls/order_and_size.html';
-export default function SignificantTermsAggDefinition(Private) {
-  let BucketAggType = Private(AggTypesBucketsBucketAggTypeProvider);
-  let createFilter = Private(AggTypesBucketsCreateFilterTermsProvider);
+
+export function AggTypesBucketsSignificantTermsProvider(Private) {
+  const BucketAggType = Private(AggTypesBucketsBucketAggTypeProvider);
+  const createFilter = Private(AggTypesBucketsCreateFilterTermsProvider);
 
   return new BucketAggType({
     name: 'significant_terms',
@@ -35,4 +35,4 @@ export default function SignificantTermsAggDefinition(Private) {
       }
     ]
   });
-};
+}
