@@ -1,9 +1,10 @@
 import _ from 'lodash';
 import editorHtml from 'ui/agg_types/controls/raw_json.html';
-import AggTypesParamTypesBaseProvider from 'ui/agg_types/param_types/base';
-export default function RawJSONAggParamFactory(Private) {
+import { AggTypesParamTypesBaseProvider } from 'ui/agg_types/param_types/base';
 
-  let BaseAggParam = Private(AggTypesParamTypesBaseProvider);
+export function AggTypesParamTypesRawJsonProvider(Private) {
+
+  const BaseAggParam = Private(AggTypesParamTypesBaseProvider);
 
   _.class(RawJSONAggParam).inherits(BaseAggParam);
   function RawJSONAggParam(config) {
@@ -26,7 +27,7 @@ export default function RawJSONAggParamFactory(Private) {
    */
   RawJSONAggParam.prototype.write = function (aggConfig, output) {
     let paramJSON;
-    let param = aggConfig.params[this.name];
+    const param = aggConfig.params[this.name];
 
     if (!param) {
       return;
@@ -45,7 +46,7 @@ export default function RawJSONAggParamFactory(Private) {
         .keys()
         .union(_.keys(b))
         .transform(function (dest, key) {
-          let val = compare(a[key], b[key]);
+          const val = compare(a[key], b[key]);
           if (val !== undefined) dest[key] = val;
         }, {})
         .value();
@@ -74,4 +75,4 @@ export default function RawJSONAggParamFactory(Private) {
   };
 
   return RawJSONAggParam;
-};
+}
