@@ -1,13 +1,24 @@
-const { clone, get } = require('lodash');
-const { resolve } = require('url');
+import { clone, get } from 'lodash';
+import { resolve } from 'url';
 
 module.exports = function (chrome, internals) {
 
-  if (internals.app) {
-    internals.app.url = resolve(window.location.href, internals.app.url);
+  if (get(internals, 'app.navLink.url')) {
+    internals.app.navLink.url = resolve(window.location.href, internals.app.navLink.url);
   }
 
   internals.appUrlStore = internals.appUrlStore || window.sessionStorage;
+  try {
+    const verifySessionStorage = 'verify sessionStorage';
+    internals.appUrlStore.setItem(verifySessionStorage, 1);
+    internals.appUrlStore.removeItem(verifySessionStorage);
+  } catch (error) {
+    throw new Error(
+      'Kibana requires access to sessionStorage, and it looks like ' +
+      'your browser is restricting it. If you\'re ' +
+      'using Safari with private browsing enabled, you can solve this ' +
+      'problem by disabling private browsing, or by using another browser.');
+  }
 
   /**
    * ui/chrome apps API
@@ -35,7 +46,7 @@ module.exports = function (chrome, internals) {
   };
 
   chrome.getAppUrl = function () {
-    return get(internals, ['app', 'url']);
+    return get(internals, ['app', 'navLink', 'url']);
   };
 
   chrome.getInjected = function (name, def) {
@@ -50,6 +61,4 @@ module.exports = function (chrome, internals) {
   chrome.setLastUrlFor = function (appId, url) {
     internals.appUrlStore.setItem(`appLastUrl:${appId}`, url);
   };
-
-
 };
