@@ -1,7 +1,7 @@
-export default function CourierFetchRequestStatus() {
+export function ReqStatusProvider() {
   return {
     ABORTED: { CourierFetchRequestStatus: 'aborted' },
     DUPLICATE: { CourierFetchRequestStatus: 'duplicate' },
     INCOMPLETE: { CourierFetchRequestStatus: 'incomplete' }
   };
-};
+}
