@@ -1,12 +1,12 @@
 import _ from 'lodash';
 import { isNumber } from 'lodash';
 
-import Notifier from 'ui/notify/notifier';
+import { Notifier } from 'ui/notify/notifier';
 
-import SearchRequestProvider from './search';
-import SegmentedHandleProvider from './segmented_handle';
+import { SearchRequestProvider } from './search';
+import { SegmentedHandleProvider } from './segmented_handle';
 
-export default function SegmentedReqProvider(es, Private, Promise, timefilter, config) {
+export function SegmentedRequestProvider(es, Private, Promise, timefilter, config) {
   const SearchReq = Private(SearchRequestProvider);
   const SegmentedHandle = Private(SegmentedHandleProvider);
 
@@ -186,11 +186,8 @@ export default function SegmentedReqProvider(es, Private, Promise, timefilter, c
 
       return indexPattern.toDetailedIndexList(timeBounds.min, timeBounds.max, this._direction)
       .then(queue => {
-        if (!_.isArray(queue)) queue = [queue];
-
         this._queue = queue;
         this._queueCreated = true;
-
         return queue;
       });
     }
@@ -336,4 +333,4 @@ export default function SegmentedReqProvider(es, Private, Promise, timefilter, c
   SegmentedReq.prototype.mergedSegment = notify.timed('merge response segment', SegmentedReq.prototype.mergedSegment);
 
   return SegmentedReq;
-};
+}
