@@ -1,6 +1,5 @@
-import _ from 'lodash';
-import CidrMask from 'ui/utils/cidr_mask';
-import uiModules from 'ui/modules';
+import { CidrMask } from 'ui/utils/cidr_mask';
+import { uiModules } from 'ui/modules';
 
 uiModules.get('kibana').directive('validateCidrMask', function () {
   return {
