@@ -1,5 +1,5 @@
 import 'ui/field_format_editor/samples/samples';
-import uiModules from 'ui/modules';
+import { uiModules } from 'ui/modules';
 import patternTemplate from 'ui/field_format_editor/pattern/pattern.html';
 
 uiModules
@@ -11,7 +11,7 @@ uiModules
     require: ['ngModel', '^fieldEditor'],
     scope: true,
     link: function ($scope, $el, attrs, cntrls) {
-      let ngModelCntrl = cntrls[0];
+      const ngModelCntrl = cntrls[0];
 
       $scope.$bind('inputs', attrs.inputs);
       $scope.$bind('placeholder', attrs.placeholder);
