@@ -1,5 +1,6 @@
 import _ from 'lodash';
-export default function (filters) {
+
+export function filterAppliedAndUnwrap(filters) {
   return _.filter(filters, 'meta.apply');
-};
+}
 
