@@ -1,7 +1,8 @@
 import _ from 'lodash';
-import FilterBarLibMapAndFlattenFiltersProvider from 'ui/filter_bar/lib/map_and_flatten_filters';
-export default function mapFlattenAndWrapFilters(Private) {
-  let mapAndFlattenFilters = Private(FilterBarLibMapAndFlattenFiltersProvider);
+import { FilterBarLibMapAndFlattenFiltersProvider } from 'ui/filter_bar/lib/map_and_flatten_filters';
+
+export function FilterBarLibMapFlattenAndWrapFiltersProvider(Private) {
+  const mapAndFlattenFilters = Private(FilterBarLibMapAndFlattenFiltersProvider);
   return function (filters) {
     return mapAndFlattenFilters(filters).then(function (filters) {
       return _.map(filters, function (filter) {
@@ -11,4 +12,4 @@ export default function mapFlattenAndWrapFilters(Private) {
       });
     });
   };
-};
+}
