@@ -1,5 +1,5 @@
 import _ from 'lodash';
-import uiModules from 'ui/modules';
+import { uiModules } from 'ui/modules';
 // Shorts dot notated strings
 // eg: foo.bar.baz becomes f.b.baz
 // 'foo.bar.baz'.replace(/(.+?\.)/g,function(v) {return v[0]+'.';});
@@ -24,5 +24,3 @@ function shortDotsFilterProvider(config) {
     return filter(str);
   }
 }
-
-export default shortDotsFilterProvider;
