@@ -23,7 +23,7 @@ function omitIndicesWithoutTimeField(indices, timeFieldName) {
   return _.pick(indices, index => index.fields[timeFieldName]);
 }
 
-export default function CalculateIndicesFactory(Promise, es) {
+export function IndexPatternsCalculateIndicesProvider(es) {
 
   // Uses the field stats api to determine the names of indices that need to
   // be queried against that match the given pattern and fall within the
@@ -32,7 +32,7 @@ export default function CalculateIndicesFactory(Promise, es) {
     return getFieldStats(pattern, timeFieldName, start, stop)
     .then(resp => omitIndicesWithoutTimeField(resp.indices, timeFieldName))
     .then(indices => sortIndexStats(indices, timeFieldName, sortDirection));
-  };
+  }
 
   // creates the configuration hash that must be passed to the elasticsearch
   // client
@@ -78,4 +78,4 @@ export default function CalculateIndicesFactory(Promise, es) {
   }
 
   return calculateIndices;
-};
+}
