@@ -1,8 +1,9 @@
-import IndexedArray from 'ui/indexed_array';
+import { IndexedArray } from 'ui/indexed_array';
 import _ from 'lodash';
-import IndexPatternsFieldProvider from 'ui/index_patterns/_field';
-export default function FieldListProvider(Private) {
-  let Field = Private(IndexPatternsFieldProvider);
+import { IndexPatternsFieldProvider } from 'ui/index_patterns/_field';
+
+export function IndexPatternsFieldListProvider(Private) {
+  const Field = Private(IndexPatternsFieldProvider);
 
   _.class(FieldList).inherits(IndexedArray);
   function FieldList(indexPattern, specs) {
@@ -16,4 +17,4 @@ export default function FieldListProvider(Private) {
   }
 
   return FieldList;
-};
+}
