@@ -5,12 +5,12 @@ import _ from 'lodash';
  * @param  {Error|String} err
  * @returns {string}
  */
-export default function formatESMsg(err) {
-  let rootCause = _.get(err, 'resp.error.root_cause');
+export function formatESMsg(err) {
+  const rootCause = _.get(err, 'resp.error.root_cause');
   if (!rootCause) {
     return; //undefined
   }
 
-  let result = _.pluck(rootCause, 'reason').join('\n');
+  const result = _.pluck(rootCause, 'reason').join('\n');
   return result;
-};
+}
