@@ -1,15 +1,15 @@
-import angular from 'angular';
 import $ from 'jquery';
 import _ from 'lodash';
-import EventsProvider from 'ui/events';
-export default function ReflowWatcherService(Private, $rootScope, $http) {
+import { EventsProvider } from 'ui/events';
 
-  let EventEmitter = Private(EventsProvider);
-  let $body = $(document.body);
-  let $window = $(window);
+export function ReflowWatcherProvider(Private, $rootScope, $http) {
 
-  let MOUSE_EVENTS = 'mouseup';
-  let WINDOW_EVENTS = 'resize';
+  const EventEmitter = Private(EventsProvider);
+  const $body = $(document.body);
+  const $window = $(window);
+
+  const MOUSE_EVENTS = 'mouseup';
+  const WINDOW_EVENTS = 'resize';
 
   _.class(ReflowWatcher).inherits(EventEmitter);
   /**
@@ -64,4 +64,4 @@ export default function ReflowWatcherService(Private, $rootScope, $http) {
   };
 
   return new ReflowWatcher();
-};
+}
