@@ -1,4 +1,4 @@
-export default function getUnhashableStatesProvider(getAppState, globalState) {
+export function getUnhashableStatesProvider(getAppState, globalState) {
   return function getUnhashableStates() {
     return [getAppState(), globalState].filter(Boolean);
   };
