@@ -2,15 +2,12 @@
 import chrome from 'ui/chrome';
 
 import sinon from 'sinon';
-import Notifier from 'ui/notify/notifier';
-import { setupAutoRelease } from 'auto-release-sinon';
+import { Notifier } from 'ui/notify/notifier';
 
 import './test_harness.less';
 import 'ng_mock';
 import { setupTestSharding } from './test_sharding';
 
-// Setup auto releasing stubs and spys
-setupAutoRelease(sinon, window.afterEach);
 setupTestSharding();
 
 // allows test_harness.less to have higher priority selectors
