@@ -1,7 +1,6 @@
-import _ from 'lodash';
 import 'ui/notify/directives';
-import uiModules from 'ui/modules';
-let typeahead = uiModules.get('kibana/typeahead');
+import { uiModules } from 'ui/modules';
+const typeahead = uiModules.get('kibana/typeahead');
 
 
 typeahead.directive('kbnTypeaheadInput', function ($rootScope) {
@@ -11,8 +10,8 @@ typeahead.directive('kbnTypeaheadInput', function ($rootScope) {
     require: ['^ngModel', '^kbnTypeahead'],
 
     link: function ($scope, $el, $attr, deps) {
-      let model = deps[0];
-      let typeaheadCtrl = deps[1];
+      const model = deps[0];
+      const typeaheadCtrl = deps[1];
 
       typeaheadCtrl.setInputModel(model);
 
