@@ -1,8 +1,7 @@
-import _ from 'lodash';
 import listTemplate from 'ui/typeahead/partials/typeahead-items.html';
 import 'ui/notify/directives';
-import uiModules from 'ui/modules';
-let typeahead = uiModules.get('kibana/typeahead');
+import { uiModules } from 'ui/modules';
+const typeahead = uiModules.get('kibana/typeahead');
 
 
 typeahead.directive('kbnTypeaheadItems', function () {
