@@ -3,18 +3,18 @@ import moment from 'moment';
 import dateMath from '@elastic/datemath';
 
 // Assume interval is in the form (value)(unit), such as "1h"
-let INTERVAL_STRING_RE = new RegExp('^([0-9\\.]*)\\s*(' + dateMath.units.join('|') + ')$');
+const INTERVAL_STRING_RE = new RegExp('^([0-9\\.]*)\\s*(' + dateMath.units.join('|') + ')$');
 
-export default function parseInterval(interval) {
-  let matches = String(interval).trim().match(INTERVAL_STRING_RE);
+export function parseInterval(interval) {
+  const matches = String(interval).trim().match(INTERVAL_STRING_RE);
 
   if (!matches) return null;
 
   try {
-    let value = parseFloat(matches[1]) || 1;
-    let unit = matches[2];
+    const value = parseFloat(matches[1]) || 1;
+    const unit = matches[2];
 
-    let duration = moment.duration(value, unit);
+    const duration = moment.duration(value, unit);
 
     // There is an error with moment, where if you have a fractional interval between 0 and 1, then when you add that
     // interval to an existing moment object, it will remain unchanged, which causes problems in the ordered_x_keys
@@ -23,7 +23,7 @@ export default function parseInterval(interval) {
     // adding 0.5 days until we hit the end date. However, since there is a bug in moment, when you add 0.5 days to
     // the start date, you get the same exact date (instead of being ahead by 12 hours). So instead of returning
     // a duration corresponding to 0.5 hours, we return a duration corresponding to 12 hours.
-    let selectedUnit = _.find(dateMath.units, function (unit) {
+    const selectedUnit = _.find(dateMath.units, function (unit) {
       return Math.abs(duration.as(unit)) >= 1;
     });
 
@@ -31,4 +31,4 @@ export default function parseInterval(interval) {
   } catch (e) {
     return null;
   }
-};
+}
