@@ -1,4 +1,6 @@
-let qs = {};
+import { encodeQueryComponent } from '../../../utils';
+
+export const QueryString = {};
 
 /*****
 /*** orignally copied from angular, modified our purposes
@@ -12,32 +14,12 @@ function tryDecodeURIComponent(value) {
   catch (e) {} // eslint-disable-line no-empty
 }
 
-/**
- * This method is intended for encoding *key* or *value* parts of query component. We need a custom
- * method because encodeURIComponent is too aggressive and encodes stuff that doesn't have to be
- * encoded per http://tools.ietf.org/html/rfc3986:
- *    query         = *( pchar / "/" / "?" )
- *    pchar         = unreserved / pct-encoded / sub-delims / ":" / "@"
- *    unreserved    = ALPHA / DIGIT / "-" / "." / "_" / "~"
- *    pct-encoded   = "%" HEXDIG HEXDIG
- *    sub-delims    = "!" / "$" / "&" / "'" / "(" / ")"
- *                     / "*" / "+" / "," / ";" / "="
- */
-function encodeUriQuery(val, pctEncodeSpaces) {
-  return encodeURIComponent(val)
-    .replace(/%40/gi, '@')
-    .replace(/%3A/gi, ':')
-    .replace(/%24/g, '$')
-    .replace(/%2C/gi, ',')
-    .replace(/%20/g, (pctEncodeSpaces ? '%20' : '+'));
-}
-
 /**
  * Parses an escaped url query string into key-value pairs.
  * @returns {Object.<string,boolean|Array>}
  */
-qs.decode = function (keyValue) {
-  let obj = {};
+QueryString.decode = function (keyValue) {
+  const obj = {};
   let keyValueParts;
   let key;
 
@@ -46,7 +28,7 @@ qs.decode = function (keyValue) {
       keyValueParts = keyValue.split('=');
       key = tryDecodeURIComponent(keyValueParts[0]);
       if (key !== void 0) {
-        let val = keyValueParts[1] !== void 0 ? tryDecodeURIComponent(keyValueParts[1]) : true;
+        const val = keyValueParts[1] !== void 0 ? tryDecodeURIComponent(keyValueParts[1]) : true;
         if (!obj[key]) {
           obj[key] = val;
         } else if (Array.isArray(obj[key])) {
@@ -65,24 +47,24 @@ qs.decode = function (keyValue) {
  * @param  {Object} obj
  * @return {String}
  */
-qs.encode = function (obj) {
-  let parts = [];
-  let keys = Object.keys(obj).sort();
+QueryString.encode = function (obj) {
+  const parts = [];
+  const keys = Object.keys(obj).sort();
   keys.forEach(function (key) {
-    let value = obj[key];
+    const value = obj[key];
     if (Array.isArray(value)) {
       value.forEach(function (arrayValue) {
-        parts.push(qs.param(key, arrayValue));
+        parts.push(QueryString.param(key, arrayValue));
       });
     } else {
-      parts.push(qs.param(key, value));
+      parts.push(QueryString.param(key, value));
     }
   });
   return parts.length ? parts.join('&') : '';
 };
 
-qs.param = function (key, val) {
-  return encodeUriQuery(key, true) + (val === true ? '' : '=' + encodeUriQuery(val, true));
+QueryString.param = function (key, val) {
+  return encodeQueryComponent(key, true) + (val === true ? '' : '=' + encodeQueryComponent(val, true));
 };
 
 /**
@@ -91,7 +73,7 @@ qs.param = function (key, val) {
  * @return {Object} - returns an object describing the start/end index of the url in the string. The indices will be
  *                    the same if the url does not have a query string
  */
-qs.findInUrl = function (url) {
+QueryString.findInUrl = function (url) {
   let qsStart = url.indexOf('?');
   let hashStart = url.lastIndexOf('#');
 
@@ -110,9 +92,9 @@ qs.findInUrl = function (url) {
   };
 };
 
-qs.replaceParamInUrl = function (url, param, newVal) {
-  let loc = qs.findInUrl(url);
-  let parsed = qs.decode(url.substring(loc.start + 1, loc.end));
+QueryString.replaceParamInUrl = function (url, param, newVal) {
+  const loc = QueryString.findInUrl(url);
+  const parsed = QueryString.decode(url.substring(loc.start + 1, loc.end));
 
   if (newVal != null) {
     parsed[param] = newVal;
@@ -120,9 +102,7 @@ qs.replaceParamInUrl = function (url, param, newVal) {
     delete parsed[param];
   }
 
-  let chars = url.split('');
-  chars.splice(loc.start, loc.end - loc.start, '?' + qs.encode(parsed));
+  const chars = url.split('');
+  chars.splice(loc.start, loc.end - loc.start, '?' + QueryString.encode(parsed));
   return chars.join('');
 };
-
-export default qs;
