@@ -1,8 +1,8 @@
-import _ from 'lodash';
-import VislibComponentsZeroInjectionOrderedXKeysProvider from './ordered_x_keys';
+import { VislibComponentsZeroInjectionOrderedXKeysProvider } from './ordered_x_keys';
 import VislibComponentsZeroInjectionZeroFilledArrayProvider from './zero_filled_array';
-import VislibComponentsZeroInjectionZeroFillDataArrayProvider from './zero_fill_data_array';
-export default function ZeroInjectionUtilService(Private) {
+import { VislibComponentsZeroInjectionZeroFillDataArrayProvider } from './zero_fill_data_array';
+
+export function VislibComponentsZeroInjectionInjectZerosProvider(Private) {
 
   const orderXValues = Private(VislibComponentsZeroInjectionOrderedXKeysProvider);
   const createZeroFilledArray = Private(VislibComponentsZeroInjectionZeroFilledArrayProvider);
@@ -29,4 +29,4 @@ export default function ZeroInjectionUtilService(Private) {
 
     return obj;
   };
-};
+}
