@@ -1,7 +1,7 @@
 import _ from 'lodash';
-import errors from 'ui/errors';
+import { ContainerTooSmall } from 'ui/errors';
 
-export default function ErrorHandlerFactory() {
+export function VislibLibErrorHandlerProvider() {
 
   /**
    * Common errors shared between constructors
@@ -28,10 +28,10 @@ export default function ErrorHandlerFactory() {
       const badHeight = _.isNaN(height) || height <= 0;
 
       if (badWidth || badHeight) {
-        throw new errors.ContainerTooSmall();
+        throw new ContainerTooSmall();
       }
-    };
+    }
   }
 
   return ErrorHandler;
-};
+}
