@@ -1,9 +1,10 @@
 import $ from 'jquery';
 import _ from 'lodash';
-import sequencer from 'ui/utils/sequencer';
-import EventsProvider from 'ui/events';
-import ReflowWatcherProvider from 'ui/reflow_watcher';
-export default function ResizeCheckerFactory(Private, Notifier) {
+import { sequencer } from 'ui/utils/sequencer';
+import { EventsProvider } from 'ui/events';
+import { ReflowWatcherProvider } from 'ui/reflow_watcher';
+
+export function ResizeCheckerProvider(Private, Notifier) {
 
   const EventEmitter = Private(EventsProvider);
   const reflowWatcher = Private(ReflowWatcherProvider);
@@ -200,4 +201,4 @@ export default function ResizeCheckerFactory(Private, Notifier) {
   };
 
   return ResizeChecker;
-};
+}
