@@ -4,17 +4,16 @@ import 'plugins/kbn_vislib_vis_types/controls/vislib_basic_options';
 import 'plugins/kbn_vislib_vis_types/controls/point_series_options';
 import 'plugins/kbn_vislib_vis_types/controls/line_interpolation_option';
 import 'plugins/kbn_vislib_vis_types/controls/heatmap_options';
-import VisSchemasProvider from 'ui/vis/schemas';
-import VisVisTypeProvider from 'ui/vis/vis_type';
-import AggResponsePointSeriesPointSeriesProvider from 'ui/agg_response/point_series/point_series';
+import 'plugins/kbn_vislib_vis_types/controls/point_series';
+import 'plugins/kbn_vislib_vis_types/controls/gauge_options';
+import { VisVisTypeProvider } from 'ui/vis/vis_type';
+import { AggResponsePointSeriesProvider } from 'ui/agg_response/point_series/point_series';
 import VislibVisTypeVislibRenderbotProvider from 'ui/vislib_vis_type/vislib_renderbot';
-export default function VislibVisTypeFactory(Private) {
-
-  let VisTypeSchemas = Private(VisSchemasProvider);
-  let VisType = Private(VisVisTypeProvider);
-  let pointSeries = Private(AggResponsePointSeriesPointSeriesProvider);
-  let VislibRenderbot = Private(VislibVisTypeVislibRenderbotProvider);
 
+export function VislibVisTypeVislibVisTypeProvider(Private) {
+  const VisType = Private(VisVisTypeProvider);
+  const pointSeries = Private(AggResponsePointSeriesProvider);
+  const VislibRenderbot = Private(VislibVisTypeVislibRenderbotProvider);
 
   _.class(VislibVisType).inherits(VisType);
   function VislibVisType(opts = {}) {
@@ -32,4 +31,4 @@ export default function VislibVisTypeFactory(Private) {
   };
 
   return VislibVisType;
-};
+}
